pub struct AssistantConfig {
pub name: String,
pub serial: Option<String>,
pub product: Option<String>,
}Expand description
An assistant node speaking banc-icd over postcard-rpc USB.
Fields
name: StringName tests use to look the node up, e.g. “a0”.
serial: Option<String>USB serial string (assistants surface their unique ID here).
product: Option<String>USB product string to match when serial is not given.